<?php

/**
 * Renders the controls (remove and update link) for a single hotblocks_item
 *
 * @param unknown_type $iNid
 * @param unknown_type $iDelta
 * @return unknown
 */
function hotblocks_hotblocks_item_controls($oHotblocks_Item) {
  $iNid = $oHotblocks_Item->nid;
  $iDelta = $oHotblocks_Item->delta;

  //We aren't going to show any item controls unless the user has access to at least one activity for the hotblock
  //This item block control function will return no text if there is no actions available for the block
  if (!hotblocks_block_controls($iDelta)) {
    return;
  }

  if (hotblocks_access('remove items from any hotblock', $iNid, $iDelta)) {
    $aLinks[] = hotblocks_remove_link($oHotblocks_Item);
  }

  if ($oHotblocks_Item->systemtype == 'node') {
    $oNode = node_load($iNid);
    if (node_access('update', $oNode)) {
      $aLinks[] = hotblocks_edit_link($oHotblocks_Item);
    }
  }

  if (sizeof($aLinks) > 0) {
    return '<span class="hotblocks_item-controls hotblocks-edit hotblocks_item-' . $iNid . '-' . $iDelta . '">' . implode('', $aLinks) . '</span>';
  }
}

/**
 * @todo Please document this function.
 * @see http://drupal.org/node/1354
 */
function hotblocks_remove_link($oHotblocks_Item) {
  $iNid = $oHotblocks_Item->nid;
  $iDelta = $oHotblocks_Item->delta;
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  $token = drupal_get_token("hotblocks-$iDelta-$oHotblocks_Item->hotblocks_itemid");
  $aQuery = drupal_get_destination() + array('path' => $sPath, 'token' => $token, 'js' => 1);
  if (hotblocks_check_global($oHotblocks_Item->hotblocks_itemid)) {
    $sImage = theme('image', array('path' => hotblocks_icon_path() . '/remove-global.png', 'alt' => 'Remove global ' . hotblocks_terminology()));
  }
  else {
    $sImage = theme('image', array('path' => hotblocks_icon_path() . '/remove.png', 'alt' => 'Remove ' . hotblocks_terminology() . ' from this page'));
  }
  $sText = variable_get('hotblocks_use_icons', true) ?  $sImage : 'Remove ' . hotblocks_terminology() . ' from this page';
  $sLink = l($sText, 'hotblocks/remove/' . $oHotblocks_Item->hotblocks_itemid . '/' . $iDelta, array('query' => $aQuery, 'attributes' => array('rel' => 'hotblocks_itemblock-' . $iDelta, 'class' => 'hotblocks-remove'), 'html' => true));
  return $sLink;
}

/**
 * @todo Please document this function.
 * @see http://drupal.org/node/1354
 */
function hotblocks_edit_link($oHotblocks_Item) {
  $iNid = $oHotblocks_Item->nid;
  $iDelta = $oHotblocks_Item->delta;
  $sImage = theme('image', array('path' => hotblocks_icon_path() . '/edit.png', 'alt' => 'Edit'));
  $sText = variable_get('hotblocks_use_icons', true) ?  $sImage : 'Edit';
  $sLink = l($sText, 'node/' . $iNid . '/edit', array('query' => drupal_get_destination(), 'html' => true));
  $sOutput = '<span class="hotblocks_item-controls hotblocks-edit hotblocks_item-' . $iNid . '-' . $iDelta . '">' . $sLink . '</span>';
  return $sLink;
}

/**
 * Generates the link within the thickbox that assigns a particular item to the hotblock
 */
function hotblocks_assign_to_block_link($iDelta, $oHotblocks_Item) {
  if (!$oHotblocks_Item->systemtype) {
    $oHotblocks_Item->systemtype = 'node';
  }

  $text = $oHotblocks_Item->title;
  $nid = $oHotblocks_Item->nid;
  $aQuery = drupal_get_destination() + array('path' => $_GET['path'], 'systemtype' => $oHotblocks_Item->systemtype, 'token' => drupal_get_token("hotblocks-$iDelta-$nid"));

  $aOptions = array(
    'attributes' => array(
      'class' => 'hotblocks-assign',
      'rel' => 'hotblocks_itemblock-' . $iDelta,
    ),
    'query' => $aQuery,
  );
  return l($text, 'hotblocks/assign/' . $nid . '/' . $iDelta, $aOptions);
}

////////////////////////////////////////////////////////////////////

/**
 * Renders the controls for a whole hotblocks_item block
 * Won't return anything if the user does not have acess to any of the hotblock's admin activities
 */
function hotblocks_block_controls($iDelta, $showAssignExplicit = false) {
  $sOutput = '';
  
  if (hotblocks_access('assign items to any hotblock', null, $iDelta)) {
    $sOutput .= hotblocks_assign_link($iDelta, $showAssignExplicit);
  }
  if (hotblocks_access('create items in any hotblock', null, $iDelta)) {
    $sOutput .= hotblocks_create_link($iDelta, $showAssignExplicit);
  }
  if (hotblocks_access('reorder items in any hotblock', null, $iDelta)) {
    $sOutput .= hotblocks_reorder_link($iDelta);
  }
  
  //don't put any controls into the output if contextual links are selected
  if(variable_get('hotblocks_contextual_links', false) && $sOutput) {
    if ($showAssignExplicit) {
      return "<div class='hotblocks-empty-block-with-contextual'><p>This region is currently empty and will not be displayed to end-users.</div>";//return space rather than empty string or false so checks for if(hotblocks_block_controls()) don't fail
    }
    return " ";//return space rather than empty string or false so checks for if(hotblocks_block_controls()) don't fail
  }
  
  return $sOutput;
}

/**
 * Generates the link within the block to assign items there
 */
function hotblocks_assign_link($iDelta, $showAssignExplicit = false) {
  $sExtraClass = '';
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  if ($showAssignExplicit) {
    $sExtraClass = ' donthide';
  }
  $aQuery = array ('path' => $sPath) + drupal_get_destination();
  $sImage = theme('image', array('path' => hotblocks_icon_path() . '/assign.png', 'alt' => 'Put a ' . hotblocks_terminology() . ' here'));
  $sText = variable_get('hotblocks_use_icons', true) ? $sImage : 'Put a ' . hotblocks_terminology() . ' here';
  $sLink = l($sText, 'hotblocks/assign/' . $iDelta, array('query' => $aQuery, 'attributes' => array('class' => 'hotblocks_itemthickbox' . $sExtraClass), 'html' => true));
  $sOutput = '<span class="hotblocks-controls hotblocks-assign-dialog hotblocks_item--' . $iDelta . $sExtraClass . '">' . $sLink . '</span>';
  return $sOutput;
}

/**
 * Generates the link within the block to create items there
 */
function hotblocks_create_link($iDelta, $showAssignExplicit = false) {
  $sExtraClass = '';
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  if ($showAssignExplicit) {
    $sExtraClass = ' donthide';
  }
  $aQuery = array ('path' => $sPath) + drupal_get_destination();
  $sImage = theme('image', array('path' => hotblocks_icon_path() . '/new.png', 'alt' => 'Create a new ' . hotblocks_terminology()));
  $sText = variable_get('hotblocks_use_icons', true) ? $sImage : 'Create a new ' . hotblocks_terminology();
  $sLink = l($sText, 'hotblocks/create/' . $iDelta, array('query' => $aQuery, 'attributes' => array('class' => 'hotblocks_itemthickbox' . $sExtraClass), 'html' => true));
  $sOutput = '<span class="hotblocks-controls hotblocks-create hotblocks_item--' . $iDelta . $sExtraClass . '">' . $sLink . '</span>';
  return $sOutput;
}

/**
 * Generates the link within the block to reorder items there
 */
function hotblocks_reorder_link($iDelta) {
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  $sImage = theme('image', array('path' => hotblocks_icon_path() . '/reorder.png', 'alt' => 'Reorder ' . hotblocks_terminology(true)));
  $sText = variable_get('hotblocks_use_icons', true) ?  $sImage : 'Reorder ' . hotblocks_terminology(true);
  $sLink = l($sText, 'hotblocks/reorder/' . $iDelta, array('attributes' => array('class' => array('hotblocks-reorder'), 'rel' => 'hotblocks_itemblock-' . $iDelta), 'html' => true, 'query' => drupal_get_destination() + array('path' => $sPath)));
  $sOutput = '<span class="hotblocks-controls hotblocks_item--' . $iDelta . '">' . $sLink . '</span>';
  return $sOutput;
}

//////////////CONTEXTUAL LINK RELATED////////////
/**
 * Renders the controls (remove and update link) for a single hotblocks_item
 *
 * @param unknown_type $iNid
 * @param unknown_type $iDelta
 * @return unknown
 */
function hotblocks_hotblocks_item_contextual_controls($oHotblocks_Item, &$renderableArray) {
  $iNid = $oHotblocks_Item->nid;
  $iDelta = $oHotblocks_Item->delta;

  //We aren't going to show any item controls unless the user has access to at least one activity for the hotblock
  //This item block control function will return no text if there is no actions available for the block
  if (!hotblocks_block_controls($iDelta)) {
    return;
  }

  if (hotblocks_access('remove items from any hotblock', $iNid, $iDelta)) {
    $aLinks['remove'] = hotblocks_contextual_item_remove_link($oHotblocks_Item);
  }

  if (sizeof($aLinks) > 0) {
    
    $renderableArray['#contextual_links']['hotblocks-item'] = array(
      'hotblocks',
      array('nid' => $iNid, 'delta' => $iDelta, 'hotblocks_itemid' => $oHotblocks_Item->hotblocks_itemid)
    );
    
  }
}

/**
 * returns a contextual link for a hotblock 
 *
 * @param $iDelta - hotblocks block id
 */
function hotblocks_contextual_link($type, $iDelta) {
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  
  $links = array(
    'assign' => array(
      'title' => t('Put a ' . hotblocks_terminology() . ' here'),
      'attributes' => array(
        'class' => 'hotblocks_itemthickbox'
      )
    ),
    'create' => array(
      'title' => t('Create a new ' . hotblocks_terminology()),
      'attributes' => array(
        'class' => 'hotblocks_itemthickbox'
      )
    ),
    'reorder' => array(
      'title' => t('Reorder ' . hotblocks_terminology(true)),
      'attributes' => array(
        'class' => 'hotblocks-reorder',
        'rel' => 'hotblocks_itemblock-' . $iDelta
      )
    )
  );
  //TODO: if the type is "create" and there are no content types that are hotblocks, don't put a "create" link on the page
  
  if ( isset($links[$type]) ) {
    $aQuery = array ('height' => 400, 'width' => 400, 'path' => $sPath) + drupal_get_destination();
    $sText = $links[$type]['title'];
    return array(
      'title' => $sText,
      'href' => 'hotblocks/'.$type.'/' . $iDelta,
      'query' => $aQuery,
      'attributes' => $links[$type]['attributes']
    );  
  }
  
  return false; //unknown type parameter
}

/**
 * Return an array useable as a contextual link
 */
function hotblocks_contextual_item_remove_link($oHotblocks_Item) {
  $iNid = $oHotblocks_Item->nid;
  $iDelta = $oHotblocks_Item->delta;
  $sPath = isset($_GET['path']) ? $_GET['path'] : $_GET['q'];
  $token = drupal_get_token("hotblocks-$iDelta-$oHotblocks_Item->hotblocks_itemid");
  $aQuery = drupal_get_destination() + array('path' => $sPath, 'token' => $token, 'js' => 1);
  $sText = 'Remove ' . hotblocks_terminology() . ' from this page';
  return array(
    'title' => $sText,
    'href' => 'hotblocks/remove/' . $oHotblocks_Item->hotblocks_itemid . '/' . $iDelta,
    'query' => $aQuery, 
    'attributes' => array('rel' => 'hotblocks_itemblock-' . $iDelta, 'class' => 'hotblocks-remove')
  );
}