<?php

/**
 * Non-ajax page callback.
 * Prints a table of 'add node' links for each nodetype allowed to be a hotblocks_item
 */
function hotblocks_create_hotblocks_item_page() {
  foreach (hotblocks_get_types() as $sType) {
    $aInfo = content_types($sType);
    if (node_access('create', $aInfo['type'])) {
      $aRows[] = array(l('Create "' . $aInfo['name'] . '"'/*.hotblocks_terminology()*/, 'node/add/' . $aInfo['url_str'] . '/hotblocks_item'));
    }
  }
  return theme('table', array('header' => array(), 'rows' => $aRows));
}

/**
 * Callback for page
 */
function hotblocks_overview_by_path() {
  $output = '<div>Global items will not be listed for every page that they will appear, since they would appear on every page of the site (provided their block is enabled).  Global items will be shown for the original page the were added.</div>';
  /////////////////////Hotblocks listed by page///////////////////
  $blockNames = hotblocks_get_blocknames_array();
  $pageresult = db_query("SELECT DISTINCT p.path FROM {hotblocks} p WHERE path != '' ORDER BY p.path");
  foreach ($pageresult as $oPage) {
    $result = db_query("SELECT n.title, n.type, p.* FROM {hotblocks} p LEFT JOIN {node} n ON n.nid = p.nid WHERE ((p.path = :path AND global = 0) OR (p.global = 1)) ORDER BY p.delta, p.weight, n.title", array(':path' => $oPage->path));
    foreach ($result as $oRow ) {
      if ($oRow->systemtype == 'block') {
        $block = db_query("SELECT * FROM {block} WHERE bid = :bid", array(':bid' => $oRow->nid))->fetchObject();
        $oRow->title = hotblocks_get_block_title_by_bid($block);
        $oRow->type = 'Block';

        $actions = array(
          l('Configure block', "admin/structure/block/configure/$block->module/$block->delta", array('query' => drupal_get_destination())),
          l('Remove', "hotblocks/remove/$oRow->hotblocks_itemid/$oRow->delta&path=$oRow->path", array('query' => drupal_get_destination())),
        );
      }

      if ($oRow->systemtype == 'node') {
        $oRow->type = node_type_get_name($oRow->type);

        $actions = array(
          l('View', "node/$oRow->nid"),
          l('Edit', "node/$oRow->nid/edit", array('query' => drupal_get_destination())),
          l('Remove', "hotblocks/remove/$oRow->hotblocks_itemid/$oRow->delta&path=$oRow->path", array('query' => drupal_get_destination())),
          l('Delete', "node/$oRow->nid/delete", array('query' => drupal_get_destination())),
        );
      }

      if ($oRow->global == 1) {
        $page = '(Global)';
      }
      else {
        $page = 'No'; //l(drupal_get_path_alias($oRow->path),$oRow->path);
      }

      $aTableRows[] = array(
        $oRow->systemtype == 'node' ? l($oRow->title, "node/$oRow->nid") : $oRow->title,
        $oRow->type,
        $page,
        $blockNames[$oRow->delta],
        $oRow->weight ? $oRow->weight : '(none)',
        implode(' | ', $actions),
      );

    }
    $aHeader = array('Name', 'Content Type', 'Global', 'Block', 'Weight', 'Action');
    if (sizeof($aTableRows) < 1) {
      $aTableRows = array(array('None'));
      $aHeader = array();
    }
    $output .=  '<div class="admin-panel">' . theme('table', array('header' => $aHeader, 'rows' => $aTableRows, 'attributes' => array(), 'caption' => "<h3>Page: " . l(drupal_get_path_alias($oPage->path), $oPage->path) . "</h3>")) . '</div>';
    unset($aTableRows);
  }

  return $output;
}

/**
 * @TODO Regular block display prefers to show the following order:
 * 1. Unweighted globals (not ordered or ordered as the DB prefers)
 * 2. All weighted hotblocks (global or not) for the block and path unless we are on node/add in which case only globals.
 * 3. Unweighted non-globals for the block and path
 * However, the overview functions currently sort by weight & path (this function) block, weight, & title
 *
 *
 * @return unknown
 */
function hotblocks_overview_by_block() {
  $output = '';

  /////////////////////Hotblocks listed by block///////////////////
  $blockNames = hotblocks_get_blocknames_array();
  foreach ($blockNames as $i => $name) {
    $aTableRows = array();
    $result = db_query("SELECT n.title, n.type, p.* FROM {hotblocks} p LEFT JOIN {node} n ON n.nid = p.nid  WHERE p.delta = :delta ORDER BY p.weight, p.path", array(':delta' => $i));
    foreach($result as $oRow) {
      if ($oRow->systemtype == 'block') {
        $block = db_query("SELECT * FROM {block} WHERE bid = :bid", array(':bid' => $oRow->nid))->fetchObject();
        $oRow->title = hotblocks_get_block_title_by_bid($block);
        $oRow->type = 'Block';

        $actions = array(
          l('Configure block', "admin/structure/block/configure/$block->module/$block->delta", array('query' => drupal_get_destination())),
          l('Remove', "hotblocks/remove/$oRow->hotblocks_itemid/$oRow->delta&path=$oRow->path", array('query' => drupal_get_destination())),
        );
      }

      if ($oRow->systemtype == 'node') {
        $oRow->type = node_type_get_name($oRow->type);

        $actions = array(
          l('View', "node/$oRow->nid"),
          l('Edit', "node/$oRow->nid/edit", array('query' => drupal_get_destination())),
          l('Remove', "hotblocks/remove/$oRow->hotblocks_itemid/$oRow->delta&path=$oRow->path", array('query' => drupal_get_destination())),
          l('Delete', "node/$oRow->nid/delete", array('query' => drupal_get_destination())),
        );
      }

      if ($oRow->global == 1) {
        $page = '(Global)';
      }
      else {
        $page = l(drupal_get_path_alias($oRow->path), $oRow->path);
      }

      $aTableRows[] = array(
        $oRow->systemtype == 'node' ? l($oRow->title, "node/$oRow->nid") : $oRow->title,
        $oRow->type,
        $page,
        $oRow->weight ? $oRow->weight : '(none)',
        implode(' | ', $actions),
      );

    }
    $aHeader = array('Name', 'Content Type', 'Page', 'Weight', 'Action');
    if (sizeof($aTableRows) < 1) {
      $aTableRows = array(array('None'));
      $aHeader = array();
    }
    $output .=  '<div class="admin-panel">' . theme('table', array('header' => $aHeader, 'rows' => $aTableRows, 'attributes' => array(), 'caption' => "<h3>Block: $name</h3>")) . '</div>';
  }

  return $output;
}

/**
 * Function is not used.
 * This code formerly existed in hotblocks_overview_by_block(), but was found to be excessive
 * It could still be useful logic to preserve, so we'll keep it here to simplify the aforementioned
 * function without deleting it completely.
 */
function hotblocks_available_content_page() {
  /////////////////////Unassigned hotblocks that have hotblocks_item status///////////////////
  if (variable_get('hotblocks_show_all_nodes_of_hotblocks_item_type', true)) {
    $aHotblocks_ItemTypes = hotblocks_get_types();
    $sTypes = implode('\',\'', $aHotblocks_ItemTypes);
    // @TODO Please convert this statement to the D7 database API syntax.
    $result = db_query("SELECT DISTINCT n.nid, n.type, n.title FROM {node} n LEFT JOIN {hotblocks} p ON n.nid = p.nid WHERE n.type IN('" . $sTypes . "') AND  (p.delta = 0 OR p.delta IS NULL) AND p.path IS NULL ORDER BY n.title ASC");
  }
  else {
    $result = db_query("SELECT n.title, n.type, p.* FROM {hotblocks} p, {node} n WHERE p.delta = 0 AND p.path IS NULL AND n.nid = p.nid ORDER BY n.title ASC");
  }
  
  $aTableRows = array();
  foreach($result as $oRow) {
      if(!db_query("SELECT nid FROM {hotblocks} p WHERE p.delta > 0 AND p.path IS NOT NULL AND nid = :nid", array(':nid' => $oRow->nid))->fetchField()) {
      $actions = array(
        l('View', "node/$oRow->nid"),
        l('Edit', "node/$oRow->nid/edit", array('query' => drupal_get_destination())),
        l('Delete', "node/$oRow->nid/delete", array('query' => drupal_get_destination())),
      );

      $aTableRows[] = array(
        l($oRow->title, 'node/' . $oRow->nid),
        node_type_get_name($oRow->type),
        implode(' | ', $actions),
      );
    }
  }
  $aHeader = array('Name', 'Content Type', 'Action');
  if (sizeof($aTableRows) < 1) {
    $aTableRows = array(array('None'));
    $aHeader = array();
  }
  $output .= '<div class="admin-panel">' . theme('table', array('header' => $aHeader, 'rows' => $aTableRows, 'attributes' => array(), 'caption' => '<h3>Available but unassigned ' . hotblocks_terminology(true, true) . '</h3>')) . '</div>';
  unset($aTableRows);
}

/////////////Functions related to taxonomy overview page:
/**
 * Would be nice to have the option of showing all terms in an opened state, or remove toggling altogether so they dont have to be opened everytime
 *
 * @param $iDelta - hotblocks_item block id
 * @return Rendered markup of taxonomy tree with all hotblocks_item nodes shown
 */
function hotblocks_taxonomy_page($iDelta = 0) {
  if (!module_exists('taxonomy')) {
    return 'The taxonomy module must be enabled to user this feature.';
  }
  $aTree = taxonomy_get_tree(variable_get('hotblocks_vocabulary', 0), 0, 1);
  return '<div class="hotblocks-taxonomy">' . hotblocks_taxonomy_build($aTree, $iDelta) . '</div>';
}

/**
 * Generate category trees for taxonomies
 */
function hotblocks_taxonomy_build($aTree, $iDelta = 0, $depth = -1) {
  //if($bExpandable) { //@todo provide option for always expanded?
  $sToggler = hotblocks_toggler();
  //}
  $depth++;
  foreach ($aTree as $oTerm) {
    $oTerm->depth = $depth;
    $bHasChildren = false;

    $result = db_query("SELECT tid FROM {taxonomy_term_hierarchy} WHERE parent = :parent", array(':parent' => $oTerm->tid));
    while ($row = db_fetch_object($result)) {
      $bHasChildren = true;
    }
    $count = taxonomy_term_count_nodes($oTerm->tid);
    if ($count > 0) {
      $bHasChildren = true;
    }

    $link = '<span class="hotblocks_item-folder">' . $oTerm->name . '</span>';

    //Tack on the toggler control if we are using expandable controls
    if (!$bHasChildren) {
      $sToggler = null;
      $toggleable = '';
      $toggleRow = '';
    }
    else {
      $toggleable = 'toggleable';
      $toggleRow = 'toggleRow';
    }

    //////List items in the term
    $result = taxonomy_select_nodes(array($oTerm->tid));
    $kids = null;
    while ($oRow = db_fetch_object($result)) {
      if (!hotblocks_access('assign items to any hotblock', db_query("SELECT type FROM {node} WHERE nid = :nid", array(':nid' => $oRow->nid))->fetchField(), $iDelta) || !hotblocks_access('view node', $oRow->nid)) {
        continue;
      }
      $sImage = theme('image', array('path' => hotblocks_icon_path('16x16') . '/page-icon.png', 'width' => 'Folder full', 'height' => 'Folder full', 'alt' => array('align' => 'absmiddle')));
      if ($iDelta > 0) {
        //If we have a delta, we'll provide links that will assign the hotblocks_item to that block
        $nlink = hotblocks_assign_to_block_link($iDelta, $oRow);
      }
      else {
        //Show regular node link
        $nlink = l($oRow->title, "node/$oRow->nid");
      }
      $kids .= '<div class="prow hb-depth-' . ($oTerm->depth + 1) . ' ' . hotblocks_even_odd() . '">' . $sImage . $nlink . '</div>';
    }

    //////Make term markup with an icon indicating whether or not it is empty
    if ($count > 0) {
      $sImage = theme('image', array('path' => hotblocks_icon_path('16x16') . '/folder-full.png', 'width' => 'Folder full', 'height' => 'Folder full', 'alt' => array('align' => 'absmiddle')));
    }
    else {
      $sImage = theme('image', array('path' => hotblocks_icon_path('16x16') . '/folder.png', 'width' => 'Folder empty', 'height' => 'Folder empty', 'alt' => array('align' => 'absmiddle')));
    }
    $output .=
      '<div rel="' . $oTerm->depth . '" class="prow ' . $toggleable . ' hb-depth-' . $oTerm->depth . ' vid-' . $oTerm->vid . ' first-letter-' . $first . '">' .
         '<div class="' . $toggleRow . '">' .
           $sToggler .
           $sImage .
           $link .
         '</div>' .
        hotblocks_taxonomy_build(taxonomy_get_tree($oTerm->vid, $oTerm->tid, 1), $iDelta, $depth) .
        $kids .
      '</div>';
  }
  return $output;
}

/**
 * @todo Please document this function.
 * @see http://drupal.org/node/1354
 */
function hotblocks_toggler($class = "toggle", $sExtraText = null, $bExpanded = false, $bInlineStyles = true) {
  $sExtraText = $sExtraText ?  ' ' . $sExtraText : null;

  if ($bInlineStyles) {
    if ($bExpanded) {
      $a = ' style="display:none;" ';
    }
    else {
      $b = ' style="display:none;" ';
    }
  }

  return sprintf('
	<span class="%1$sContainer">
		<span class="%1$s expand" %2$s>
			<a href="javascript:;" class="expand">[+]' . $sExtraText . '</a>
		</span>
		<span class="%1$s contract" %3$s>
			<a href="javascript:;" class="contract">[-]' . $sExtraText . '</a>
		</span>
	</span>', $class, $a, $b);
}

/**
 * Return the string 'hotblocks-even' or 'hotblocks-odd' in alternating succession.  Starts with 'hotblocks-even';
 * Used for css classes.
 */
function hotblocks_even_odd() {
  static $i = 'hotblocks-odd';
  if ($i == 'hotblocks-odd') {
    $i = 'hotblocks-even';
  }
  else {
    $i = 'hotblocks-odd';
  }

  return $i;
}