//Define a namespame for our functions
Drupal.hotblocks = {};

//Show a blank colorbox (it will have a loading animation in it by default)
Drupal.hotblocks.loader = function() {
  jQuery.colorbox({
    //We use 'initialWidth' and height because regular height and width never are used
    //since the colorbox never finished (since it has no content)
    initialWidth: "200px",
    initialHeight: "60px",
    opacity: ".3",
    overlayClose: false
  });
  return;
};

//Close the loader
Drupal.hotblocks.unloader = function() {
  jQuery.colorbox.close();
};

//A variable to store the hotblock of the last clicked item (jquery element)
Drupal.hotblocks.$hotblock = null;


Drupal.behaviors.hotblocks = {
  attach: function(context, settings) {
    jQuery('.donthide',context).show();
    
    //Open a modal when these links are clicked:
    jQuery('a.hotblocks_itemthickbox, area.hotblocks_itemthickbox, input.hotblocks_itemthickbox', context).click(function(e) {
      //Find the parent block and put it in a var
      Drupal.hotblocks.$hotblock = jQuery(this).closest('.hotblocks_itemblock');
      
      //Get the href of the clicked link
      var link_href = jQuery(this).attr('href');

      //Open the href of the link in a colorbox
      var settings = {
        href: link_href,
        width: "940px",
        height: "620px",
        onComplete: function() {}
      };
      jQuery.colorbox(settings);
      return false;
    });
    
    //The create links within the hotblocks 'create' modal
    jQuery('.hotblocks_item-create', context).click(function() {
      //We just want to make sure to close the modal before allowing the browser's 
      //default behavior on this, since if overlay module is on we won't be leaving the page
      jQuery.colorbox.close();
    });
    

    //Click handler for direct actions - finish assigning an item, directly remove an item, or show the reorder form
    jQuery('.hotblocks-assign, .hotblocks-remove, .hotblocks-reorder', context).click(function() {
      //The href of the link that was clicked
      var href = jQuery(this).attr('href');
      
      //Add an argument to the URL if the global checkbox is checked (assign modal only)
      if(jQuery("#hotblocks-global:checked").length) {
        href += '&global=1';
      }
      
      //Find the parent block
      if(jQuery(this).hasClass('hotblocks-assign')) {
        //Use the $hotblock that was last stored
      }
      else {
        Drupal.hotblocks.$hotblock  = jQuery(this).closest('.hotblocks_itemblock');
      }

      //Show the loading progress bar
      Drupal.hotblocks.loader();
      
      //Replace the hotblock's content with markup retrieved from the server
      Drupal.hotblocks.$hotblock.load(href,function() {
        Drupal.attachBehaviors(Drupal.hotblocks.$hotblock);
        Drupal.hotblocks.unloader();
      });
      return false;
    });
   
    //Ajaxformify the hotblocks reorder form
    jQuery('#hotblocks-reorder-form',context).ajaxForm({
      target: null,   //We'll populate this at the time the form is submitted
      beforeSubmit:  function(arr, $form, options) {
        //Show the loading modal
        Drupal.hotblocks.loader();
        
        //Extrapolate the target object from the form element - used to update with response markup (our parent block)
        options.target = $form.closest('.hotblocks_itemblock');
      },
      success: function(responseText, statusText, xhr, $form) {
        //Reattach Drupal behaviors to our block
        Drupal.attachBehaviors(this);
        
        //Remove the loader
        Drupal.hotblocks.unloader();
      }
    });
    
    //Toggler system - hide or unhide child items when a parent is expanded
    jQuery(".toggle a", context).click(function(event){
      var el = jQuery(this.parentNode.parentNode.parentNode.parentNode)
      var next;

      var depth = Number(jQuery(el).attr('rel'))+1;

      jQuery('.toggle',this.parentNode.parentNode.parentNode).toggle();
      jQuery('.depth-'+depth,el).toggle();
      
      return false;
    });
  }
}
